from setuptools import setup, find_packages
 
with open("README.md", "r") as readme_file:
    readme = readme_file.read()
 
requirements = ["requests>=2","beautifulsoup4"]

setup(
    name="searchoffer",
    version="0.0.1",
    author="ayaz abdi",
    author_email="mayazabdi@gmail.com",
    description="Python library suggestqueries google api",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/mahekan/searchoffer",
    packages=find_packages(),
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],
)